from bs4 import BeautifulSoup
import pandas as pd


def parser():
    # Формат: список транзакций, каждая транзакция - словарь
    # { 'shop': ... , 'date': ... , 'cost': ... , 'category': ... }
    result = []

    with open('index.html', 'r') as f:
        file_to_parse = f.read()

    soup = BeautifulSoup(file_to_parse, 'html.parser')
    soup.prettify()

    trs = soup.find_all('div', {'class': 'trs_it'})

    for tr in trs:
        tr_data = tr.contents[0]

        # 1. Магазин
        tr_shop = tr_data.contents[0].text.strip()

        # 2. Дата транзакции (строка)
        tr_date = str(tr_data.contents[1].contents[1]['data-date'])

        # 3. Стоимость
        tr_cost_parent = tr_data.contents[2].contents[2].contents[0]
        tr_cost_head = str(tr_cost_parent.contents[0])
        tr_cost_tail = str(tr_cost_parent.contents[1].contents[0])
        tr_cost = tr_cost_head + tr_cost_tail

        # Нормализуем стоимость
        tr_cost = tr_cost.replace(',', '.')
        tr_cost = tr_cost.replace('\u202f', '')
        tr_cost_number = float(tr_cost)
        tr_cost = '{:.2f}'.format(tr_cost_number)

        # 4. Категория
        tr_cat = tr_data.contents[3].contents[1].contents[0].contents[0]

        result.append({
            'date': tr_date,
            'category': tr_cat,
            'shop': tr_shop,
            'cost': tr_cost,
        })

    return result


def convert_to_dataframe(parsed_data):
    converted_data = {}
    keys = list(parsed_data[0].keys())
    for key in keys:
        values = []
        for tr in parsed_data:
            values.append(tr[key])
        converted_data[key] = values
    return converted_data


def export_to_excel(data):
    dframe = pd.DataFrame(data)
    dframe.to_excel('transactions.xlsx', index=False)


def export_to_csv(data):
    dframe = pd.DataFrame(data)
    dframe.to_csv('transactions.csv', index=False)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sbpars', 'sbpars.scripts']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'flake8>=6.0.0,<7.0.0',
 'openpyxl>=3.0.10,<4.0.0',
 'pandas>=1.5.2,<2.0.0']

entry_points = \
{'console_scripts': ['sbpars = sbpars.scripts.sbpars:main']}

setup_kwargs = {
    'name': 'sbpars',
    'version': '0.3.0',
    'description': '',
    'long_description': '## sbpars - simply bank ordering parser\n\n### Что это?\n\nЭто простой парсер в форматы .csv и .xlsx для данных, выгружаемых из истории операций по карте одного банка. Написано и предназначено для личного использования: я веду учёт личных финансов в таблице и устал забивать руками каждый платёж по карте.\n\nПрограмма не производит никаких взаимодействий с сайтом банка и личным кабинетом клиента по сети, не использует чужие данные и вообще не даёт доступа ни к чему такому, к чему изначально нет доступа у пользователя. Функционал программы ограничен предоставлением данных, изначально доступных пользователю, в удобной форме таблицы.\n\n### Как использовать?\n\nЗаходим в личный кабинет в историю операций по карте. Кликаем на кнопку "Отчёт по карте". Настраиваем период, за который нужна выгрузка. Сохраняем страницу средствами браузера.\n\nОткрываем консоль, заходим в папку сохраненной страницы с окончанием "_files". Приложению для работы нужен файл index.html, он находится в данной папке.\n\nДалее два варианта: можно установить утилиту через pip, можно работать с исходным кодом.\n\n*Вариант 1*\n\nУстанавливаем и запускаем в папке, где находится index.html:\n```\npip install sbpars\nsbpars\n```\n\n*Вариант 2*\n\nКопируем index.html в папку со скриптом и запускаем\n\n```\npip install poetry\nmake start\n```\n\nЕсли всё прошло успешно, то в этой же папке появятся файлы transactions с расширениями .csv и .xlsx со списком транзакций\n',
    'author': 'qmka',
    'author_email': 'eidolonzx@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
from sbpars.app import parser, export_to_csv, export_to_excel


def main():
    print("Hi! I parse sberbank transactions file.\nTrying to parse...")
    data = parser()
    print("Successfully parsed index.html file")
    export_to_csv(data)
    print("Successfully exported to .csv table")
    export_to_excel(data)
    print("Successfully exported to .xslx table\nWell done!")


if __name__ == '__main__':
    main()
